@@ -2,14 +2,6 @@ use chrono::{DateTime, Utc};
 use chrono_tz::Tz;
 use std::fs;
 
-pub fn basename(path: &str) -> &str {
-    let mut pieces = path.rsplit('/');
-    match pieces.next() {
-        Some(p) => p,
-        None => path,
-    }
-}
-
 pub fn get_timezone() -> Option<String> {
     if let Ok(link) = fs::read_link("/etc/localtime") {
         let mut components = link.components();
